@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '5.012';
+our $VERSION = '5.016';
 
 sub new {
     my ($class) = @_;
@@ -911,7 +911,7 @@ sub PT::Assignment::X {
 sub PT::AccessorAssignment::X {
     my ($class, $className) = @_;
 
-    my $variableName = $class->{ScalarVariable}->X($className);
+    my $variableName = $class->{HashKeyStringValue}->X($className);
     my $rhs = $class->{RHS}->X($className);
 
     my $accessorAssignment  = '$class->{"' . $className . '"}->{"'. $variableName .'"} = ' . $rhs .';';
@@ -987,7 +987,7 @@ sub PT::ObjectFunctionCall::X {
 
 sub PT::ClassAccessor::X {
     my ($class, $className) = @_;
-    my $variableName = $class->{ScalarVariable}->X($className);
+    my $variableName = $class->{HashKeyStringValue}->X($className);
 
     my $classAccessor = '$class->{"' . $className . '"}->{"'. $variableName .'"}';
     return $classAccessor;
@@ -1325,7 +1325,7 @@ sub PT::LogicalOr::X {
 
 my $parser = qr {
     <nocontext:>
-    <debug: on>
+    # <debug: on>
 
     <Lang>
     <objrule:  PT::Lang>                       <[Class]>+
@@ -1480,8 +1480,9 @@ my $parser = qr {
 
     <objrule:  PT::STDIN>                      <LessThan>  <TokenSTDIN> <GreaterThan>
 
-    <objrule:  PT::AccessorAssignment>         <TokenClass> <Dot> <ScalarVariable> <Equal> <RHS> <SemiColon>
-    <objrule:  PT::ClassAccessor>              <TokenClass> <Dot> <ScalarVariable>
+    <objtoken: PT::HashKeyStringValue>         [a-zA-Z]+?
+    <objrule:  PT::AccessorAssignment>         <TokenClass> <Dot> <HashKeyStringValue> <Equal> <RHS> <SemiColon>
+    <objrule:  PT::ClassAccessor>              <TokenClass> <Dot> <HashKeyStringValue>
     <objrule:  PT::ClassFunctionReturn>        <TokenClass> <Dot> <FunctionName> <LParen> <Parameters>? <RParen>
 
     <objrule:  PT::ArrayAssignment>            <ArrayElement> <Equal> <RHS> <SemiColon>
